
"""Build / Upload to pypi."""

from setuptools import setup

setup(
    name="fibonacci-heap-mod",
    version="1.02",
    py_modules=['fibonacci_heap_mod'],

    # metadata for upload to PyPI
    author="Daniel Richard Stromberg",
    author_email="strombrg@gmail.com",
    description='Pure Python Fibonacci Heap (Priority Queue)',
    long_description='''
A Pure Python Fibonacci Heap implementation of a Priority Queue is provided.

It passes pylint, pyflakes, pycodestyle, and pydocstyle; is thoroughly unit tested; and runs on CPython 2.7,
CPython 3.[3456789] & CPython 3.10, Pypy 5.10.0, Pypy3 5.10.0 and Jython 2.7.
''',
    license="Apache v2",
    keywords="Fibonacci Heap, Priority Queue",
    url='http://stromberg.dnsalias.org/~strombrg/fibonacci-heap-mod/',
    platforms='Cross platform',
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 3",
        ],
)

